@@ -1,3 +1,4 @@
+import concurrent
 import os
 
 from types import MethodType
@@ -250,7 +251,14 @@ class QalxAdapter(object):
         return self.find(many=False, limit=2, query=query, **kwargs)
 
     def find(
-        self, query=None, sort=None, skip=0, limit=25, many=True, **kwargs
+        self,
+        query=None,
+        sort=None,
+        skip=0,
+        limit=25,
+        many=True,
+        include_session_tags=True,
+        **kwargs,
     ):
         """
         Method for listing entities.
@@ -260,6 +268,8 @@ class QalxAdapter(object):
         :param skip: The number of results to skip (offset) by
         :param limit: How many results should the response be limited to
         :param many: Should many entities be returned or just a single one
+        :param include_session_tags:    Should the tags for the session be
+                                        included in the query. Default is True
         :param kwargs: kwargs to query by
         :return:
         """
@@ -268,7 +278,7 @@ class QalxAdapter(object):
         self.session.log.debug(
             f"find {self.entity_class.entity_type} with {list_endpoint}"
         )
-        if self.session.tags:
+        if include_session_tags and self.session.tags:
             # There are tags on this session, modify the query given (if
             # necessary) to include a filter that applies those tags.
             empty_and = {"$and": []}
@@ -429,7 +439,9 @@ class QalxUnpackableAdapter(QalxAdapter):
 
     @staticmethod
     def _child_list_response(child_adapter, query, **kwargs):
-        return child_adapter.find(query=query, **kwargs)
+        return child_adapter.find(
+            query=query, include_session_tags=False, **kwargs
+        )
 
     def _child_list_request(
         self, entity, kids, child_adapter, query_key="guid", child_fields=None
@@ -444,32 +456,27 @@ class QalxUnpackableAdapter(QalxAdapter):
         :return: A list of unpacked child_adapter.entity_class entities
         """
         unpacked_entities = []
-
-        for _page in entity._chunks(kids, chunk_size=100):
-            # Chunk to avoid hitting maximum request size
-            values = list(filter(None, _page))
-            query = {query_key: {"$in": values}}
-            _resp = self._child_list_response(
-                child_adapter=child_adapter, query=query, fields=child_fields
-            )
-            unpacked_entities += _resp["data"]
-            while _resp["query"]["next"] is not None:
-                # We got a paginated response so keep going through the pages
-                # until we exhaust this chunk of data
-                self.session.log.debug(
-                    f"get {self.entity_class.entity_type} with "
-                    f"{_resp['query']['next']}"
+        page_size = 100
+        _futures = []
+        with concurrent.futures.ThreadPoolExecutor() as executor:
+            for _page in entity._chunks(kids, chunk_size=page_size):
+                # Chunk to avoid hitting maximum request size
+                values = list(filter(None, _page))
+                query = {query_key: {"$in": values}}
+                _futures.append(
+                    executor.submit(
+                        self._child_list_response,
+                        child_adapter=child_adapter,
+                        query=query,
+                        fields=child_fields,
+                        limit=page_size,
+                    )
                 )
-
-                _resp = self._process_api_request(
-                    "get", _resp["query"]["next"], fields=child_fields
-                )
-
-                unpacked_entities += self._process_api_response(
-                    _resp,
-                    entity_class=QalxListEntity,
-                    child=self.child_entity_class,
-                )["data"]
+            for future in concurrent.futures.as_completed(_futures):
+                try:
+                    unpacked_entities += future.result()["data"]
+                except QalxAPIResponseError as exc:
+                    self.raise_api_response_error(exc)
         return unpacked_entities
 
     def _kids_for_lookup(self, entity):
@@ -549,11 +556,6 @@ class QalxUnpackableAdapter(QalxAdapter):
                     to_return[key] = child_entity
         return to_return
 
-    def _should_unpack(self):
-        return self.session.config[
-            "UNPACK_" + self.entity_class.entity_type.upper()
-        ]
-
     def _attempt_unpack(self, entity, **kwargs):
         """
         For the given entity will attempt
@@ -563,7 +565,7 @@ class QalxUnpackableAdapter(QalxAdapter):
         :return: The entity instance with the child_entity objects unpacked
         """
 
-        if self._should_unpack() and self.kids in entity:
+        if self.kids in entity:
             # `self.kid` might not be there if we have specified a subset
             # of fields
             unpacked_entities = self._get_child_entities(entity, **kwargs)
@@ -625,11 +627,12 @@ class QalxUnpackableAdapter(QalxAdapter):
         """
         return {k: v for k, v in kids.items()}
 
-    def get(self, guid, child_fields=None, *args, **kwargs):
+    def get(self, guid, child_fields=None, unpack=True, *args, **kwargs):
         """
         Unpackable entities need to be unpacked after retrieval
 
         :param guid: The `guid` of the entity to get
+        :param unpack: Should the adapter be unpacked. Defaults to True
         :param child_fields: A list of fields that should be returned from
         child entities
         :type child_fields: list
@@ -638,7 +641,20 @@ class QalxUnpackableAdapter(QalxAdapter):
         entity = super(QalxUnpackableAdapter, self).get(
             guid=guid, *args, **kwargs
         )
-        entity = self._attempt_unpack(entity, child_fields=child_fields)
+        if unpack is True:
+            entity = self._attempt_unpack(entity, child_fields=child_fields)
+        return entity
+
+    def reload(self, entity, unpack=True, *args, **kwargs):
+        entity = super(QalxUnpackableAdapter, self).reload(
+            entity, unpack=unpack, *args, **kwargs
+        )
+        return entity
+
+    def find_one(self, query, unpack=True, **kwargs):
+        entity = super(QalxUnpackableAdapter, self).find_one(
+            query, unpack=unpack, **kwargs
+        )
         return entity
 
     def find(self, many=True, child_fields=None, *args, **kwargs):
@@ -654,14 +670,15 @@ class QalxUnpackableAdapter(QalxAdapter):
         entities = super(QalxUnpackableAdapter, self).find(
             many=many, *args, **kwargs
         )
-        if many is False:
+        unpack = kwargs.get("unpack", True)
+        if unpack is True and many is False:
             # Only unpack a list view if we have a single entity
             entities = self._attempt_unpack(entities, child_fields=child_fields)
         return entities
 
     def save(self, entity, *args, **kwargs):
         """
-        When saving an unpacked entity the kids need to be packed.  To save
+        When saving an unpacked entity the kids need to be packed. To save
         having to unpack them again just save the original kids and replace
         them with the packed values after saving
         """
@@ -756,16 +773,17 @@ class QalxNamedEntityAdapter(QalxAdapter):
     entity.
     """
 
-    def get_by_name(self, name):
+    def get_by_name(self, name, **kwargs):
         """a single entity by name
 
         :param name: name of entity
         :type name: str
+        :param kwargs: Keyword arguments to be used in the find method
         :return: instance of `self.entity_class`
         :raises: pyqalx.errors.QalxReturnedMultipleError,
                  pyqalx.errors.QalxEntityNotFound
         """
-        return self.find_one(query={"name": name})
+        return self.find_one(query={"name": name}, **kwargs)
 
     def get_or_create(self, name, meta=None, **kwargs):
         """
