@@ -1,8 +1,6 @@
 import platform
 
-from logging import getLogger
-
-from pyqalx.config import UserConfig
+from pyqalx.config import UserConfig, Config
 from pyqalx.core.adapters import (
     QalxBlueprint,
     QalxBot,
@@ -12,8 +10,9 @@ from pyqalx.core.adapters import (
     QalxSet,
     QalxWorker,
     QalxFactory,
+    QalxNotification,
 )
-from pyqalx.core.log import configure_logging
+from pyqalx.core.log import configure_logging, session_logging_suffix
 from pyqalx.core.registry import Registry
 from pyqalx.core.tags import Tags
 from pyqalx.transport import PyQalxAPI
@@ -24,7 +23,7 @@ class QalxSession:
 
     def __init__(
         self,
-        profile_name="default",
+        profile_name=Config.default,
         config_class=None,
         skip_ini=False,
         rest_api_class=None,
@@ -32,7 +31,7 @@ class QalxSession:
     ):
         """
         :param profile_name:    profile name to get from `config_class`
-                                (default="default")
+                                (default=Config.default)
         :type profile_name: str
         :config_class:  The class for the config that will be used for this
                         session
@@ -47,22 +46,53 @@ class QalxSession:
         if config_class is None:
             config_class = UserConfig
         self.config = config_class()
-        """
-        an instance of the `config_class` (default=pyqalx.config.UserConfig())
-        """
+        self.profile_name = profile_name
         if not skip_ini:
             self.config.from_inifile(profile_name)
+        # Configure the log for this session.  This cannot be set on an
+        # instance attribute due to pickling issues with windows.  However,
+        # it needs to be configured as early as possibly after config
+        # initialisation so that if there is an unhandled exception this can be
+        # logged properly
+        self.configure_logging()
 
-        configure_logging(self.config)
         if rest_api_class is None:
             rest_api_class = PyQalxAPI
-        self.rest_api = rest_api_class(self.config)
+        self.rest_api = rest_api_class(self)
         self._registry = Registry()
         self._registry._register_defaults()
         self.tags = Tags([], rest_api=self.rest_api)
         if project_name:
             self.tags.add(name="project_name", value=project_name)
 
+    def configure_logging(self):
+        """
+        Configures the log for this session.  A log is namespace for the
+        config type and the profile name to allow a user to have multiple
+        session instances with different configs/profiles logging to different
+        places.
+        :return:An instance of logging.getLogger`
+        """
+        # Ensures that the log directories are created if they don't already
+        # exist
+        self.config._create_log_directories()
+        return configure_logging(
+            f"{session_logging_suffix(self.config)}.{self.profile_name}",
+            self.config.get("LOG_FILE_PATH"),
+            self.config.get("LOGGING_LEVEL"),
+        )
+
+    @property
+    def log(self):
+        """
+        Returns an instance of `logging.getLogger` for this QalxSession instance
+        This cannot be set as an instance attribute due to pickling issues on
+        windows.
+        Usages `QalxSession().log.<level>()`
+        :return: logging.getLogger
+        """
+        return self.configure_logging()
+
     def __setattr__(self, key, value):
         if key == "tags" and hasattr(self, "tags"):
             # The user is completely replacing the tags.
@@ -70,24 +100,18 @@ class QalxSession:
             self.tags._validate(value)
         return super(QalxSession, self).__setattr__(key, value)
 
-    @property
-    def log(self):
-        return getLogger("pyqalx.integration")
-
     def _update_config(self, config):
         """
         Method to use if the config needs to be updated after the session has
-        been created.  Used when creating a `~bot.Bot` as a `QalxSession`
-        needs to be created using a `BotConfig` and then update it with the
-        token the `~bot.Bot` needs to use to interact with the
-        `~entities.Queue`.
+        been created.
         Also updates the rest_api with the updated config
 
-        :param config:
+        :param config:A config dict
+        :type config: dict
         :return:
         """
         self.config.update(config)
-        self.rest_api = self.rest_api.__class__(self.config)
+        self.rest_api = self.rest_api.__class__(self)
 
     def register(self, cls):
         self._registry.register(cls)
@@ -100,7 +124,7 @@ class QalxSession:
         return {
             "node": platform.node(),
             "platform": platform.platform(),
-            # TODO: #3930 add more platform and IP address infos
+            "ip": self.rest_api._get_external_ip(),
         }
 
     @property
@@ -182,3 +206,13 @@ class QalxSession:
         :return: pyqalx.core.adapters.blueprint.QalxBlueprint
         """
         return QalxBlueprint(self)
+
+    @property
+    def notification(self):
+        """
+        returns a :class:`~pyqalx.core.adapters.notification.QalxNotification`
+        adapter for this session
+
+        :return: pyqalx.core.adapters.notification.QalxNotification
+        """
+        return QalxNotification(self)
