@@ -32,10 +32,16 @@ from pyqalx.core.errors import (
 from pyqalx.core.errors import QalxFactoryValidationError
 from pyqalx.factories.sectors.manager import SectorManager
 from pyqalx.factories.sectors.sectors import Sectors
-from pyqalx.factories.sectors.providers import _providers, LocalProvider
+from pyqalx.factories.sectors.providers import (
+    _providers,
+    LocalProvider,
+    AWSProvider,
+)
 from pyqalx.factories.tree import QalxTree
 from pyqalx.core.utils import _msg_user
 
+default_aws_profile = AWSProvider.default_profile_name()
+
 
 class FactoryValidateMixin:
     """Specific Validate functionality"""
@@ -197,23 +203,27 @@ class FactoryBuildMixin:
     """
 
     @staticmethod
-    def _metadata(entity, plan_bot_name):
+    def _metadata(entity, plan_bot_name=None):
         """
-        The base metadata that should be stored on the Bot entities and the
-        Item code entities created by this factory
+        The base metadata that should be stored on any entities that are linked
+        to this factory
         """
-        return {
+        metadata = {
             "_class": "pyqalx.factory",
             # Namedspaced metadata to avoid potential name clashing
             # with any custom metadata provided by the user.
             BaseFactory.PYQALX_METADATA_NAMESPACE_KEY: {
                 BaseFactory.PYQALX_METADATA_STAGE_KEY: entity["stage"],
                 BaseFactory.PYQALX_METADATA_FACTORY_GUID_KEY: entity["guid"],
-                # This enables identification between Bot entities
-                # and Item entities that contain the Bot code.
-                BaseFactory.PYQALX_METADATA_PLAN_BOT_NAME_KEY: plan_bot_name,
             },
         }
+        if plan_bot_name is not None:
+            # This enables identification between Bot entities
+            # and Item entities that contain the Bot code.
+            metadata[BaseFactory.PYQALX_METADATA_NAMESPACE_KEY][
+                BaseFactory.PYQALX_METADATA_PLAN_BOT_NAME_KEY
+            ] = plan_bot_name
+        return metadata
 
     def _add_entity(self, plan):
         """
@@ -786,6 +796,11 @@ class BaseFactory(
 
     Instance attributes
         session:        A QalxSession instance
+        user_profile:   The qalx profile to use as a user profile.
+        bot_profile:    The qalx profile to use for starting bots. Default value
+                        is according to the default bot configuration
+        aws_profile:    The AWS profile to use for remote sectors. Default value
+                        is according to boto3 defaults
         __entity: The Factory entity from the API.
         __plan:           A dictionary with the details of the plan of the factory
         __stage: The stage that the build/pack is using.  Uses the stage on the
@@ -804,8 +819,17 @@ class BaseFactory(
     PYQALX_METADATA_PLAN_BOT_NAME_KEY = "plan_bot_name"
     PYQALX_METADATA_BUILD_PATH_KEY = "build_path"
 
-    def __init__(self, session):
+    def __init__(
+        self,
+        session,
+        user_profile=UserConfig.default,
+        bot_profile=BotConfig.default,
+        aws_profile=default_aws_profile,
+    ):
         self.session = session
+        self.user_profile = user_profile
+        self.bot_profile = bot_profile
+        self.aws_profile = aws_profile
         self.__plan = None
         self.__entity = None
         self.__stage = None
@@ -964,14 +988,6 @@ class BaseFactory(
     def _plan_stage(self):
         return self._plan_stages[self.entity.stage]
 
-    @property
-    def _stage_user_profile(self):
-        return self._plan_stage.get("user_profile", UserConfig.default)
-
-    @property
-    def _stage_bot_profile(self):
-        return self._plan_stage.get("bot_profile", BotConfig.default)
-
     @property
     def stacks(self):
         """
@@ -1047,9 +1063,9 @@ class BaseFactory(
                 f"Unable to delete"
             )
 
-    def _delete_bot_code_items(self):
+    def _delete_items(self):
         """
-        Find all the bot code items for the factory entity based on their
+        Find all the items for the factory entity based on their
         metadata. Iterates through them deletes them from the API. In the
          case of an error from the API during the deleting process, the error
          is logged and printed out.
@@ -1117,6 +1133,6 @@ class BaseFactory(
             # be attempted.  If an error occurs after stack creation then
             # the stacks should be deleted
             self._delete_stacks()
-        self._delete_bot_code_items()
+        self._delete_items()
         self._delete_factory_build()
         self._delete_build_path()
