@@ -1,7 +1,8 @@
 import json
+from collections import defaultdict
 
 import yaml
-from troposphere import Tag, Tags, Template, Base64, Join, Ref, ssm
+from troposphere import Tag, Tags, Template, Base64, Join, Ref, ssm, cloudwatch
 from troposphere.ec2 import Instance
 from troposphere.iam import Role, Policy, InstanceProfile
 from troposphere.secretsmanager import Secret
@@ -233,6 +234,15 @@ class AWSStack:
         user_data = getattr(self, f"{platform}_user_data")(sector_name)
         return user_data
 
+    def _ec2_instance_logical_id(self, sector_name):
+        """
+        Helper for determining the EC2 instance logical ID for a given
+        sector
+        :param sector_name:The name of the sector from the plan
+        :return: The logical ID used in CF templates
+        """
+        return self._logical_id(sector_name, "instance")
+
     def _ec2_instance(self, sector_name):
         """
         Adds a single ec2 instance to the template.  There will be one EC2
@@ -243,7 +253,7 @@ class AWSStack:
         """
         suffix = "instance"
         instance_profile = self.refs["instance_profile"]
-        logical_id = self._logical_id(sector_name, suffix)
+        logical_id = self._ec2_instance_logical_id(sector_name)
         wait_handle = WaitConditionHandle(
             self._logical_id(sector_name, "wait_condition_handle")
         )
@@ -382,6 +392,7 @@ class AWSStack:
                 sector_name, suffix
             ),
             Roles=[self.refs["role"].RoleName],
+            DependsOn=[self.refs["role"].title],
         )
         self.template.add_resource(instance)
         self.refs["instance_profile"] = instance
@@ -439,6 +450,64 @@ class AWSStack:
                         )
                         self.template.add_resource(instance)
 
+    def _build_alarm(self, alarm_name, region_name):
+        """
+        Helper for building a specific alarm based on the alarm name
+        """
+        alarm = self.provider.factory.plan["factory"]["alarms"][alarm_name]
+        template = {}
+
+        for key, value in alarm.items():
+            if key == "AlarmActions":
+                # Alarm actions get built up from an enum
+                action_value = []
+                for action in value:
+                    action_value.append(
+                        f"arn:aws:automate:{region_name}:ec2:{action}"
+                    )
+                value = action_value
+            template[key] = value
+        return template
+
+    def _alarms(self):
+        """
+        Builds all the Cloudwatch alarms for all the instances.  The same alarm
+        is used for multiple instances if possible.
+        """
+        alarms = {}
+        dimensions = defaultdict(list)
+        depends_on = defaultdict(list)
+        for sector_name, parameters in self.stack.items():
+            alarm_name = parameters.get("alarm", None)
+            ec2_instance_logical_id = self._ec2_instance_logical_id(sector_name)
+            sector = self.provider.stack[sector_name]
+            region = sector["region_name"]
+
+            if alarm_name is not None:
+                # There is an alarm on this sector, build the base alarm
+                # template
+                logical_id = self._logical_id(alarm_name, "alarm")
+                alarms[logical_id] = self._build_alarm(alarm_name, region)
+                depends_on[logical_id].append(ec2_instance_logical_id)
+                dimensions[logical_id].append(
+                    {
+                        "Name": "InstanceId",
+                        "Value": Ref(ec2_instance_logical_id),
+                    }
+                )
+
+        for logical_id, dimension in dimensions.items():
+            metric_dimensions = [
+                cloudwatch.MetricDimension().from_dict(d=d, title=logical_id)
+                for d in dimension
+            ]
+
+            alarms[logical_id]["Dimensions"] = metric_dimensions
+            alarms[logical_id]["DependsOn"] = depends_on[logical_id]
+
+            instance = cloudwatch.Alarm(logical_id, **alarms[logical_id])
+            self.template.add_resource(instance)
+
     def _image_ids(self):
         """
         Returns the imageIDs for the given sector.  There may be multiple
@@ -480,6 +549,7 @@ class AWSStack:
             self._ec2_instance(sector_name)
             self._config_parameters(sector_name)
             self._role_policies()
+        self._alarms()
         # The user supplies the raw parameters for the EC2 instances
         # so we need to insert them into the template directly
         template = self._insert_parameters()
