@@ -105,7 +105,7 @@ def start(
     workflow,
 ):
     """
-    start the bot at TARGET
+    Start the bot at TARGET
 
     This is the import path with a colon followed by the variable name
     of the bot. e.g. `my_qalx.my_bot:bot`
@@ -149,7 +149,7 @@ def start(
 @click.argument("name")
 @click.pass_context
 def terminate_bot(ctx, name):
-    """shutdown the bot named NAME"""
+    """Shutdown the bot named NAME"""
     qalx_session = QalxSession(
         profile_name=ctx.obj.get("USER_PROFILE", UserConfig.default)
     )
@@ -180,7 +180,7 @@ def terminate_bot(ctx, name):
 @click.argument("name")
 @click.pass_context
 def stop_bot(ctx, name):
-    """stop the bot named NAME.
+    """Stop the bot named NAME.
 
     All workers to stop pulling jobs from the queue.
     """
@@ -209,7 +209,7 @@ def stop_bot(ctx, name):
 @click.argument("name")
 @click.pass_context
 def resume_bot(ctx, name):
-    """resume the bot named NAME.
+    """Resume the bot named NAME.
 
     All workers to start pulling jobs from the queue.
     """
@@ -237,7 +237,7 @@ def resume_bot(ctx, name):
 @click.argument("name")
 @click.pass_context
 def bot_info(ctx, name):
-    """print info about the bot named NAME.
+    """Print info about the bot named NAME.
 
     """
     qalx_session = QalxSession(
@@ -261,7 +261,7 @@ def bot_info(ctx, name):
 @click.argument("number", type=types.INT)
 @click.pass_context
 def terminate_workers(ctx, bot_name, number):
-    """terminate NUMBER of workers on bot named BOT_NAME."""
+    """Terminate NUMBER of workers on bot named BOT_NAME."""
     qalx_session = QalxSession(
         profile_name=ctx.obj.get("USER_PROFILE", UserConfig.default)
     )
